.. _todo-label:

TODO items
==========

* Add support for different batch systems, e.g. htcondor
* Integrate gbasf2 as another batch system
* Document the API of the task class
* Add more examples on how to do complex tasks with a full "analysis example".
* Add a function for writing into temporary files and moving automatically
* Add helper messages on events (e.g. failed)
* Clearly document that there is currently no implementation for dependencies on demand!
* port b2luigi to basf2